@@ -111,6 +111,7 @@ class Client:
         user=None,
         volumes=None,
         mount_cwd=False,
+        network=None,
     ):
         mounts = volumes or []
         if mount_cwd is True:
@@ -162,7 +163,7 @@ class Client:
     def run_command(self, container, command, user=None):
         container = self.client.containers.get(container)
         click.echo(click.style(f'Run Command: {command}', fg='green'))
-        socket = container.exec_run(
+        exit_code, socket = container.exec_run(
             cmd=command,
             tty=True,
             socket=True,
@@ -171,12 +172,20 @@ class Client:
 
         for line in socket.output:
             click.echo(line, nl=False)
+        return exit_code
 
-    def build(self, dockerfile, tag, rebuild):
-        image, _ = self.client.images.build(path='.', dockerfile=dockerfile, tag=tag, nocache=rebuild, rm=True)
+    def build(self, dockerfile, tag, rebuild, directory='.', buildargs=None):
+        image, _ = self.client.images.build(
+            path=directory,
+            dockerfile=dockerfile,
+            tag=tag,
+            nocache=rebuild,
+            rm=True,
+            buildargs=buildargs or {},
+        )
         return image.id
 
-    def get_container_data(self, name, inside=False):
+    def get_container_data(self, name, network, inside=False):
         data = {}
         try:
             container = self.client.containers.get(name)
