@@ -1,5 +1,6 @@
 import json
 import pathlib
+from unittest.mock import patch
 
 import click.testing
 import docker as docker_py
@@ -7,6 +8,7 @@ import docker as docker_py
 import pytest
 
 from teststack import import_commands
+from teststack.containers.docker import Client
 from teststack.git import get_tag
 
 
@@ -25,7 +27,6 @@ def tag():
 def attrs():
     return {
         'NetworkSettings': {
-            'IPAddress': 'fakeaddress',
             'Ports': {
                 '5432/tcp': [
                     {'HostPort': '12345'},
@@ -33,8 +34,16 @@ def attrs():
                 '5672/tcp': [
                     {'HostPort': '12537'},
                 ],
+                '6379/tcp': [
+                    {'HostPort': '19999'},
+                ],
                 '12345/tcp': [],
             },
+            'Networks': {
+                'teststack': {
+                    'IPAddress': 'fakeaddress',
+                },
+            },
         },
     }
 
@@ -63,9 +72,25 @@ def testapp_dir(main_dir):
     return main_dir / 'tests' / 'testapp'
 
 
+@pytest.fixture()
+def test_files_dir(main_dir):
+    return main_dir / 'tests' / 'files'
+
+
+@pytest.fixture()
+def client():
+    context = docker_py.ContextAPI.get_current_context()
+    if context.name == 'default':  # pragma: no branch
+        with patch('docker.from_env') as client:
+            yield client.return_value
+    else:
+        with patch('docker.DockerClient') as client:
+            yield client.return_value
+
+
 @pytest.fixture()
 def docker():
-    return docker_py.from_env()
+    return Client().client
 
 
 @pytest.fixture(autouse=True)
