@@ -1,6 +1,7 @@
 import os
 import subprocess
 from unittest import mock
+from xml.etree.ElementTree import ElementTree
 
 import pytest
 from docker.errors import NotFound
@@ -9,16 +10,14 @@ from teststack import cli
 
 
 def test_running_tests_in_containers(docker, runner, testapp_dir):
-
-    result = runner.invoke(cli, [f'--path={testapp_dir}', 'stop', 'render', 'build', 'run'])
+    result = runner.invoke(cli, [f'--path={testapp_dir}', 'stop', 'build', 'start', '-n', '-m', 'run'])
     assert result.exit_code == 0
     result = runner.invoke(cli, [f'--path={testapp_dir}', 'stop'])
     assert result.exit_code == 0
 
 
 def test_running_tests(docker, runner, testapp_dir):
-
-    result = runner.invoke(cli, [f'--path={testapp_dir}', 'stop', 'render', 'build', 'start', '-n'])
+    result = runner.invoke(cli, [f'--path={testapp_dir}', 'stop', 'build', 'start', '-n', '-m'])
     assert result.exit_code == 0
     with pytest.raises(NotFound):
         docker.containers.get('testapp_tests')
