@@ -8,16 +8,16 @@ from app.database import db
 def health_database_status():
     try:
         # to check database we will execute raw query
-        db.session.execute('SELECT 1')
+        db.session.execute("SELECT 1")
     except Exception as e:
         return False
     return True
 
 
 def health_cache_status():
-    for cache, backend in current_app.extensions['cache'].items():
+    for cache, backend in current_app.extensions["cache"].items():
         try:
-            backend._read_clients.keys()
+            backend._read_client.keys()
         except Exception as e:
             return False
     return True
@@ -29,8 +29,8 @@ class Health(MethodView):
         cache = health_cache_status()
         return jsonify(
             {
-                'status': database and cache,
-                'database': database,
-                'cache': cache,
+                "status": database and cache,
+                "database": database,
+                "cache": cache,
             }
         )
